@@ -420,162 +420,174 @@ export function registerResource(res: Resource, t: string, name: string, custom:
 async function prepareResource(label: string, res: Resource, custom: boolean, remote: boolean,
                                props: Inputs, opts: ResourceOptions): Promise<ResourceResolverOperation> {
 
-    // Simply initialize the URN property and get prepared to resolve it later on.
-    // Note: a resource urn will always get a value, and thus the output property
-    // for it can always run .apply calls.
-    let resolveURN: (urn: URN, err?: Error) => void;
-    {
-        let resolveValue: (urn: URN) => void;
-        let rejectValue: (err: Error) => void;
-        let resolveIsKnown: (isKnown: boolean) => void;
-        let rejectIsKnown: (err: Error) => void;
-        (res as any).urn = new Output(
-            res,
-            debuggablePromise(
-                new Promise<URN>((resolve, reject) => {
+    // add an entry to the rpc queue while we prepare the request.
+    // automation api inline programs that don't have stack exports can exit quickly. If we don't do this,
+    // sometimes they will exit right after `prepareResource` is called as a part of register resource, but before the
+    // .then() that adds to the queue via `runAsyncResourceOp`.
+    const done: () => void = rpcKeepAlive();
+
+    try {
+        // Simply initialize the URN property and get prepared to resolve it later on.
+        // Note: a resource urn will always get a value, and thus the output property
+        // for it can always run .apply calls.
+        let resolveURN: (urn: URN, err?: Error) => void;
+        {
+            let resolveValue: (urn: URN) => void;
+            let rejectValue: (err: Error) => void;
+            let resolveIsKnown: (isKnown: boolean) => void;
+            let rejectIsKnown: (err: Error) => void;
+            (res as any).urn = new Output(
+                res,
+                debuggablePromise(
+                    new Promise<URN>((resolve, reject) => {
+                        resolveValue = resolve;
+                        rejectValue = reject;
+                    }),
+                    `resolveURN(${label})`),
+                debuggablePromise(
+                    new Promise<boolean>((resolve, reject) => {
+                        resolveIsKnown = resolve;
+                        rejectIsKnown = reject;
+                    }),
+                    `resolveURNIsKnown(${label})`),
+                /*isSecret:*/ Promise.resolve(false),
+                Promise.resolve(res));
+
+            resolveURN = (v, err) => {
+                if (!!err) {
+                    rejectValue(err);
+                    rejectIsKnown(err);
+                } else {
+                    resolveValue(v);
+                    resolveIsKnown(true);
+                }
+            };
+        }
+
+        // If a custom resource, make room for the ID property.
+        let resolveID: ((v: any, performApply: boolean, err?: Error) => void) | undefined;
+        if (custom) {
+            let resolveValue: (v: ID) => void;
+            let rejectValue: (err: Error) => void;
+            let resolveIsKnown: (v: boolean) => void;
+            let rejectIsKnown: (err: Error) => void;
+
+            (res as any).id = new Output(
+                res,
+                debuggablePromise(new Promise<ID>((resolve, reject) => {
                     resolveValue = resolve;
                     rejectValue = reject;
                 }),
-                `resolveURN(${label})`),
-            debuggablePromise(
-                new Promise<boolean>((resolve, reject) => {
+                `resolveID(${label})`),
+                debuggablePromise(new Promise<boolean>((resolve, reject) => {
                     resolveIsKnown = resolve;
                     rejectIsKnown = reject;
-                }),
-                `resolveURNIsKnown(${label})`),
-            /*isSecret:*/ Promise.resolve(false),
-            Promise.resolve(res));
+                }), `resolveIDIsKnown(${label})`),
+                Promise.resolve(false),
+                Promise.resolve(res));
 
-        resolveURN = (v, err) => {
-            if (!!err) {
-                rejectValue(err);
-                rejectIsKnown(err);
-            } else {
-                resolveValue(v);
-                resolveIsKnown(true);
-            }
-        };
-    }
+            resolveID = (v, isKnown, err) => {
+                if (!!err) {
+                    rejectValue(err);
+                    rejectIsKnown(err);
+                } else {
+                    resolveValue(v);
+                    resolveIsKnown(isKnown);
+                }
+            };
+        }
 
-    // If a custom resource, make room for the ID property.
-    let resolveID: ((v: any, performApply: boolean, err?: Error) => void) | undefined;
-    if (custom) {
-        let resolveValue: (v: ID) => void;
-        let rejectValue: (err: Error) => void;
-        let resolveIsKnown: (v: boolean) => void;
-        let rejectIsKnown: (err: Error) => void;
+        // Now "transfer" all input properties into unresolved Promises on res.  This way,
+        // this resource will look like it has all its output properties to anyone it is
+        // passed to.  However, those promises won't actually resolve until the registerResource
+        // RPC returns
+        const resolvers = transferProperties(res, label, props);
 
-        (res as any).id = new Output(
-            res,
-            debuggablePromise(new Promise<ID>((resolve, reject) => {
-                resolveValue = resolve;
-                rejectValue = reject;
-            }),
-                `resolveID(${label})`),
-            debuggablePromise(new Promise<boolean>((resolve, reject) => {
-                resolveIsKnown = resolve;
-                rejectIsKnown = reject;
-            }), `resolveIDIsKnown(${label})`),
-            Promise.resolve(false),
-            Promise.resolve(res));
+        /** IMPORTANT!  We should never await prior to this line, otherwise the Resource will be partly uninitialized. */
 
-        resolveID = (v, isKnown, err) => {
-            if (!!err) {
-                rejectValue(err);
-                rejectIsKnown(err);
-            } else {
-                resolveValue(v);
-                resolveIsKnown(isKnown);
-            }
-        };
-    }
+        // Before we can proceed, all our dependencies must be finished.
+        const explicitDirectDependencies = new Set(await gatherExplicitDependencies(opts.dependsOn));
 
-    // Now "transfer" all input properties into unresolved Promises on res.  This way,
-    // this resource will look like it has all its output properties to anyone it is
-    // passed to.  However, those promises won't actually resolve until the registerResource
-    // RPC returns
-    const resolvers = transferProperties(res, label, props);
+        // Serialize out all our props to their final values.  In doing so, we'll also collect all
+        // the Resources pointed to by any Dependency objects we encounter, adding them to 'propertyDependencies'.
+        const [serializedProps, propertyToDirectDependencies] = await serializeResourceProperties(label, props);
 
-    /** IMPORTANT!  We should never await prior to this line, otherwise the Resource will be partly uninitialized. */
+        // Wait for the parent to complete.
+        // If no parent was provided, parent to the root resource.
+        const parentURN = opts.parent
+            ? await opts.parent.urn.promise()
+            : await getRootResource();
 
-    // Before we can proceed, all our dependencies must be finished.
-    const explicitDirectDependencies = new Set(await gatherExplicitDependencies(opts.dependsOn));
+        let providerRef: string | undefined;
+        let importID: ID | undefined;
+        if (custom) {
+            const customOpts = <CustomResourceOptions>opts;
+            importID = customOpts.import;
+            providerRef = await ProviderResource.register(opts.provider);
+        }
 
-    // Serialize out all our props to their final values.  In doing so, we'll also collect all
-    // the Resources pointed to by any Dependency objects we encounter, adding them to 'propertyDependencies'.
-    const [serializedProps, propertyToDirectDependencies] = await serializeResourceProperties(label, props);
-
-    // Wait for the parent to complete.
-    // If no parent was provided, parent to the root resource.
-    const parentURN = opts.parent
-        ? await opts.parent.urn.promise()
-        : await getRootResource();
-
-    let providerRef: string | undefined;
-    let importID: ID | undefined;
-    if (custom) {
-        const customOpts = <CustomResourceOptions>opts;
-        importID = customOpts.import;
-        providerRef = await ProviderResource.register(opts.provider);
-    }
-
-    const providerRefs: Map<string, string> = new Map<string, string>();
-    if (remote) {
-        const componentOpts = <ComponentResourceOptions>opts;
-        expandProviders(componentOpts);
-        if (componentOpts.providers) {
-            for (const provider of componentOpts.providers as ProviderResource[]) {
-                const pref = await ProviderResource.register(provider);
-                if (pref) {
-                    providerRefs.set(provider.getPackage(), pref);
+        const providerRefs: Map<string, string> = new Map<string, string>();
+        if (remote) {
+            const componentOpts = <ComponentResourceOptions>opts;
+            expandProviders(componentOpts);
+            if (componentOpts.providers) {
+                for (const provider of componentOpts.providers as ProviderResource[]) {
+                    const pref = await ProviderResource.register(provider);
+                    if (pref) {
+                        providerRefs.set(provider.getPackage(), pref);
+                    }
                 }
             }
         }
-    }
 
-    // Collect the URNs for explicit/implicit dependencies for the engine so that it can understand
-    // the dependency graph and optimize operations accordingly.
+        // Collect the URNs for explicit/implicit dependencies for the engine so that it can understand
+        // the dependency graph and optimize operations accordingly.
 
-    // The list of all dependencies (implicit or explicit).
-    const allDirectDependencies = new Set<Resource>(explicitDirectDependencies);
+        // The list of all dependencies (implicit or explicit).
+        const allDirectDependencies = new Set<Resource>(explicitDirectDependencies);
 
-    const allDirectDependencyURNs = await getAllTransitivelyReferencedResourceURNs(explicitDirectDependencies);
-    const propertyToDirectDependencyURNs = new Map<string, Set<URN>>();
+        const allDirectDependencyURNs = await getAllTransitivelyReferencedResourceURNs(explicitDirectDependencies);
+        const propertyToDirectDependencyURNs = new Map<string, Set<URN>>();
 
-    for (const [propertyName, directDependencies] of propertyToDirectDependencies) {
-        addAll(allDirectDependencies, directDependencies);
+        for (const [propertyName, directDependencies] of propertyToDirectDependencies) {
+            addAll(allDirectDependencies, directDependencies);
 
-        const urns = await getAllTransitivelyReferencedResourceURNs(directDependencies);
-        addAll(allDirectDependencyURNs, urns);
-        propertyToDirectDependencyURNs.set(propertyName, urns);
-    }
-
-    // Wait for all aliases. Note that we use `res.__aliases` instead of `opts.aliases` as the former has been processed
-    // in the Resource constructor prior to calling `registerResource` - both adding new inherited aliases and
-    // simplifying aliases down to URNs.
-    const aliases = [];
-    const uniqueAliases = new Set<string>();
-    for (const alias of (res.__aliases || [])) {
-        const aliasVal = await output(alias).promise();
-        if (!uniqueAliases.has(aliasVal)) {
-            uniqueAliases.add(aliasVal);
-            aliases.push(aliasVal);
+            const urns = await getAllTransitivelyReferencedResourceURNs(directDependencies);
+            addAll(allDirectDependencyURNs, urns);
+            propertyToDirectDependencyURNs.set(propertyName, urns);
         }
-    }
 
-    return {
-        resolveURN: resolveURN,
-        resolveID: resolveID,
-        resolvers: resolvers,
-        serializedProps: serializedProps,
-        parentURN: parentURN,
-        providerRef: providerRef,
-        providerRefs: providerRefs,
-        allDirectDependencyURNs: allDirectDependencyURNs,
-        propertyToDirectDependencyURNs: propertyToDirectDependencyURNs,
-        aliases: aliases,
-        import: importID,
-    };
+        // Wait for all aliases. Note that we use `res.__aliases` instead of `opts.aliases` as the former has been processed
+        // in the Resource constructor prior to calling `registerResource` - both adding new inherited aliases and
+        // simplifying aliases down to URNs.
+        const aliases = [];
+        const uniqueAliases = new Set<string>();
+        for (const alias of (res.__aliases || [])) {
+            const aliasVal = await output(alias).promise();
+            if (!uniqueAliases.has(aliasVal)) {
+                uniqueAliases.add(aliasVal);
+                aliases.push(aliasVal);
+            }
+        }
+
+        return {
+            resolveURN: resolveURN,
+            resolveID: resolveID,
+            resolvers: resolvers,
+            serializedProps: serializedProps,
+            parentURN: parentURN,
+            providerRef: providerRef,
+            providerRefs: providerRefs,
+            allDirectDependencyURNs: allDirectDependencyURNs,
+            propertyToDirectDependencyURNs: propertyToDirectDependencyURNs,
+            aliases: aliases,
+            import: importID,
+        };
+
+    } finally {
+        // free the RPC queue
+        done();
+    }
 }
 
 function addAll<T>(to: Set<T>, from: Set<T>) {
@@ -618,7 +630,7 @@ async function getAllTransitivelyReferencedResourceURNs(resources: Set<Resource>
     // Then we filter to only include Custom and Remote resources.
     const transitivelyReachableCustomResources =
         [...transitivelyReachableResources]
-        .filter(r => CustomResource.isInstance(r) || (r as ComponentResource).__remote);
+            .filter(r => CustomResource.isInstance(r) || (r as ComponentResource).__remote);
     const promises = transitivelyReachableCustomResources.map(r => r.urn.promise());
     const urns = await Promise.all(promises);
     return new Set<string>(urns);
@@ -802,8 +814,8 @@ export function listResourceOutputs<U extends Resource>(
             }).then<any[]>(({ outputs }) => utils.values(outputs)),
         )
         .map<ResolvedResource<U>>(({ type: typ, outputs }) => {
-            return { ...outputs, __pulumiType: typ };
-        })
+        return { ...outputs, __pulumiType: typ };
+    })
         .filter(typeFilter);
 }
 
